.. _chapter_database:

Chapter: Database
=================

In this chapter, we introduce you to the **PyAutoFit**'s database functionality that allows one to output all model-fitting results
to a relational database. This means model-fits to large datasets can then be loaded and inspected in a Jupyter notebook.

You can start the tutorials right now by going to `our binder <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/HEAD>`_
and navigating to the folder ``notebooks/howtofit/chapter_database``. They are also on the `autofit_workspace <https://github.com/Jammy2211/autofit_workspace>`_.

The chapter contains the following tutorials:

`Tutorial 1: Fitting Multiple Datasets <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_database/tutorial_1_fitting_multiple_datasets.ipynb>`_
- Fitting a model to multiple similar datasets.

`Tutorial 2: Aggregator <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_database/tutorial_2_aggregator.ipynb>`_
- Loading large libraries of results using in-built database tools.

`Tutorial 3: Querying <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_database/tutorial_3_querying.ipynb>`_
- Filtering the loaded results to find specific results of interest.

`Tutorial 4: Data and Models <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_database/tutorial_4_data_and_models.ipynb>`_
- Replotting the model, data and fits of a set of results.
